Crate rivescript_core

Crate rivescript_core 

RiveScript Core

This crate provides common types and traits that are useful for RiveScript and third-party plugin modules. For example, the [LanguageLoader] for foreign programming-language Object Macro Handlers lives here so that the RiveScript crate and external implementations can both reference it.

Modules

ast
RiveScript Abstract Syntax Tree
macros
Foreign Programming Language Object Macros

Constants

BEGIN_REQUEST
BEGIN_TOPIC
DEFAULT_DEPTH
DEFAULT_TOPIC
ERR_NO_MATCH
ERR_NO_REPLY
MAX_HISTORY
MAX_STARS
TAG_OK
UNDEFINED