RiveScript Abstract Syntax Tree
The AST is a parsed object representing all of the contents of a RiveScript bot brain. It is the output object that you get when you load_file() or stream() a RiveScript document (or several). It contains all of the useful inner contents of the RiveScript brain, including global bot variables, substitutions and other configuration that was defined via RiveScript.
Structs
- AST
- Root of the “abstract syntax tree” representing a RiveScript source document and its useful contents.
- Condition
- Condition holds the contents of a *Condition command in RiveScript.
- Object
- Object represents a parsed object macro from a RiveScript source document.
- Topic
- Topic is a group of triggers.
- Trigger
- Trigger represents a pattern that matches a user’s message.