Object

Struct Object 

pub struct Object {
    pub name: String,
    pub language: String,
    pub code: Vec<String>,
}
Object represents a parsed object macro from a RiveScript source document.

Object macros have a name, a programming language, and an array of their source code as defined in the RiveScript document. It is up to the interpreter program to understand how to parse an object macro and make it executable.

Fields

name: Stringlanguage: Stringcode: Vec<String>

Implementations

Source

impl Object

pub fn new(name: &str, language: &str, code: Vec<String>) -> Self