Topic

Struct Topic 

pub struct Topic {
    pub name: String,
    pub triggers: Vec<Trigger>,
    pub includes: HashMap<String, bool>,
    pub inherits: HashMap<String, bool>,
}
Topic is a group of triggers.

All triggers belong to a topic, with the default topic being a special one named “random”. To move the current user into a different topic, use the {topic} tag, for example {topic=random}. A user can ONLY match triggers that are defined in their current topic, or any triggers that are ‘included’ or ‘inherited’ into their current topic.

Fields

name: Stringtriggers: Vec<Trigger>includes: HashMap<String, bool>inherits: HashMap<String, bool>

Implementations

Source

impl Topic

pub fn set_includes(&mut self, includes: String)

pub fn set_inherits(&mut self, inherits: String)

pub fn add_trigger(&mut self, trigger: Trigger)