pub struct Trigger {
pub trigger: String,
pub reply: Vec<String>,
pub condition: Vec<Condition>,
pub redirect: String,
pub previous: String,
}Expand description
Trigger represents a pattern that matches a user’s message.
It is the base unit of intelligence for your chatbot. A trigger of “hello bot” will match when the user says that phrase, and can pair a set of replies (multiple OK, which will be chosen at random) to be sent when that trigger is matched.
Fields
trigger: Stringreply: Vec<String>condition: Vec<Condition>redirect: Stringprevious: StringImplementations