Parser

Struct Parser 

pub struct Parser {}
The RiveScript language parser.

Implementations

Source

impl Parser

pub fn new() -> Self

Create a new instance of the parser. It takes no parameters.

pub fn parse(&self, filename: &str, contents: String) -> Result<AST, String>

Parse RiveScript source code and return the Abstract Syntax Tree.

The filename is used only for syntax error reporting (so the filename and line number can be included in the error).