RiveScript Core
This crate provides common types and traits that are useful for RiveScript and third-party plugin modules. For example, the [LanguageLoader] for foreign programming-language Object Macro Handlers lives here so that the RiveScript crate and external implementations can both reference it.